@@ -304,18 +304,21 @@ class Register():
         files to register.
         """
         if self.args.str_filesubstr:
-            # First create a list of all the files...
-            self.l_files    = [
-                f                                                       \
-                    for f in listdir(self.args.str_xcrdir)              \
-                        if isfile(join(self.args.str_xcrdir, f))
-            ]
-            # Now filter them according to the passed filesubstr
-            self.l_files    = [
-                x                                                       \
-                    for y in self.args.str_filesubstr.split(',')        \
-                        for x in self.l_files if y in x
-            ]
+            try:
+                # First create a list of all the files...
+                self.l_files    = [
+                    f                                                       \
+                        for f in listdir(self.args.str_xcrdir)              \
+                            if isfile(join(self.args.str_xcrdir, f))
+                ]
+                # Now filter them according to the passed filesubstr
+                self.l_files    = [
+                    x                                                       \
+                        for y in self.args.str_filesubstr.split(',')        \
+                            for x in self.l_files if y in x
+                ]
+            except:
+                pass
         elif self.args.str_xcrdirfile:
             self.l_files.append(self.args.str_xcrfile)
         elif len(self.args.localFileList):
@@ -381,7 +384,10 @@ class Register():
         """
         dl_run      : list  = []
         d_run       : dict  = {'status' : False}
+        current     : int   = 0
+        total       : int   = len(self.l_files)
         for str_file in self.l_files:
+            current        += 1
             d_run           = self.DICOMfile_mapsUpdate(
                                 self.DICOMfile_register(
                                     self.packer.DICOMfile_read(
@@ -390,8 +396,8 @@ class Register():
                                                 str_file
                                             )
                                     ),
-                                str_file)
-                            )
+                                str_file),
+                            current, total)
             # Before returning, we need to "sanitize" some of the
             # DICOMfile_read fields, specifically the DICOM read
             # payload that can be very full/noisy. Here we just
@@ -416,14 +422,33 @@ class Register():
             if 'date' in  field.lower():
                 try:
                     d_pacsData[field]  = datetime.strptime(
-                                            d_pacsData[field], 
+                                            d_pacsData[field],
                                             "%Y%m%d").strftime('%Y-%m-%d'
                                         )
                 except:
                     pass
             if 'patientage' in field.lower():
                 str_age     = d_pacsData['PatientAge']
-                if not str_age[-1].isnumeric():
+                age         = -1
+                if not len(str_age):
+                    # The PatientAge in the DICOM is empty -- a not
+                    # irregular occurence. In this case, we calculate
+                    # the age as the difference between
+                    #
+                    #           StudyDate - PatientBirthDate
+                    #
+                    # assuming these are also existant.
+                    if len(d_pacsData['StudyDate']) and len(d_pacsData['PatientBirthDate']):
+                        try:
+                            date_study = datetime.strptime(d_pacsData['StudyDate'], "%Y-%m-%d")
+                        except:
+                            date_study = datetime.strptime(d_pacsData['StudyDate'], "%Y%m%d")
+                        try:
+                            date_birth  = datetime.strptime(d_pacsData['PatientBirthDate'], "%Y-%m-%d")
+                        except:
+                            date_birth  = datetime.strptime(d_pacsData['PatientBirthDate'], "%Y%m%d")
+                        age = abs((date_study - date_birth).days)
+                elif not str_age[-1].isnumeric():
                     try:
                         age     = int(str_age[0:-1])
                     except:
@@ -433,7 +458,14 @@ class Register():
                     if AS == 'M':   age *= 30
                     if AS == 'W':   age *= 7
                     if AS == 'D':   age *= 1
-                    d_pacsData['PatientAge']    = '%s' % age
+                else:
+                    # Here the age is specified as a string with no suffix
+                    # qualifier. We assume age is then in years
+                    try:
+                        age = int(str_age) * 365
+                    except:
+                        pass
+                d_pacsData['PatientAge']    = '%s' % age
         return d_pacsData
 
     def DICOMfile_register(self, d_DICOMfile_read, str_file)    -> dict:
@@ -451,7 +483,8 @@ class Register():
             'PatientID',    'PatientName',      'PatientBirthDate',
             'PatientAge',   'PatientSex',       'ProtocolName',
             'StudyDate',    'StudyDescription', 'StudyInstanceUID',
-            'Modality',     'SeriesDescription','SeriesInstanceUID'
+            'Modality',     'SeriesDescription','SeriesInstanceUID',
+            'AccessionNumber'
         ]
         if d_DICOMfile_read['status']:
             for k in l_DICOMtags:
@@ -486,14 +519,14 @@ class Register():
             'd_CUBE_register_pacs_file' :   d_register
         }
 
-    def DICOMfile_mapsUpdate(self, d_DICOMfile_register)    -> dict:
+    def DICOMfile_mapsUpdate(self, d_DICOMfile_register,
+                             current = 0, total = 0)    -> dict:
         """
         Interact with the SMDB object to update JSON mapping information
         recording this registration operation.
         """
         b_status        :   bool    = False
         d_register      :   dict    = {}
-
         if d_DICOMfile_register['status']:
             b_status    = True
             self.smdb.housingDirs_create()
@@ -504,6 +537,10 @@ class Register():
             self.smdb.d_DICOM   = d_DICOMfile_register['d_DICOMfile_read']['d_DICOM']['d_dicomSimple']
             now                 = datetime.now()
             self.smdb.seriesData('register', 'info',        d_register)
+            self.smdb.seriesData('register', 'objectCounter',     {
+                'current'   : current,
+                'total'     : total
+            })
             self.smdb.seriesData('register', 'timestamp',   now.strftime("%Y-%m-%d, %H:%M:%S"))
             if len(self.args.CUBE):
                 self.smdb.seriesData('register', 'CUBE',
