@@ -150,7 +150,6 @@ class Report(Base):
             try:
                 str_value   = d_DICOMfields[str_DICOMtag]['value']
             except:
-                # pudb.set_trace()
                 if str_DICOMtag == 'PatientAge':
                     """
                     Sometimes the PatientAge is not returned
@@ -160,18 +159,22 @@ class Report(Base):
                     """
                     str_value   = patientAge_calculate(d_DICOMfields)
                 if str_DICOMtag == 'seriesStatus':
+                    # pudb.set_trace()
                     if 'then' in self.arg['reportData']:
                         d_then      = self.arg['reportData']['then']
                         d_status    = [v for k, v in d_then.items() if 'status' in k][0]
                         d_study     = d_status['study'][studyCount]
                         l_series    = d_study[next(iter(d_study))]
-                        d_series    = l_series[seriesCount]
-                        str_value   = self.seriesStatus_print(
-                            studyIndex          = studyCount,
-                            seriesIndex         = seriesCount,
-                            status              = d_series,
-                            SeriesDescription   = d_DICOMfields['SeriesDescription']['value']
-                                        )
+                        try:
+                            d_series    = l_series[seriesCount]
+                            str_value   = self.seriesStatus_print(
+                                studyIndex          = studyCount,
+                                seriesIndex         = seriesCount,
+                                status              = d_series,
+                                SeriesDescription   = d_DICOMfields['SeriesDescription']['value']
+                            )
+                        except:
+                            str_value   = "Status error for studyIndex %d / seriesIndex %d."
             return str_value
 
         def block_build(
@@ -496,7 +499,7 @@ class Report(Base):
                     'Study contains %d series' % len(ld_seriesDesc)
                 ]
                 l_instanceSummary       = [
-                    'All series contain %d images' %                        \
+                    'All series contain %d images\n' %                      \
                          sumColElements([ld_seriesUID[i][str_colToSum]      \
                              for i in range(0, len(ld_seriesUID))])
                 ]
@@ -679,7 +682,7 @@ class Report(Base):
                 str_packedCount         = '%03d' % d_status['images']['packed']['count']
                 str_pushedCount         = '%03d' % d_status['images']['pushed']['count']
                 str_registeredCount     = '%03d' % d_status['images']['registered']['count']
-                str_status              = '%25s : %20s : %20s ' % \
+                str_status              = '%15s : %15s : %15s │' % \
                     (
                         d_status['state']['study'],
                         d_status['state']['series'],
@@ -701,7 +704,7 @@ class Report(Base):
                         str_seriesInstanceUID   = ''
                 if d_status['status']:
                     str_line                =  \
-                        ' [ PACS:%s/JSON:%s/DCM:%s/PUSH:%s/REG:%s ] │ ' %                             \
+                        ' [ PACS:%s/JSON:%s/DCM:%s/PUSH:%s/REG:%s ] │ ' %      \
                             (
                                 str_requestedCount, str_receivedCount, str_packedCount,
                                 str_pushedCount, str_registeredCount
@@ -710,7 +713,7 @@ class Report(Base):
                     str_line                =  str_status
 
                 str_line += ' ' + str_seriesDescription
-                str_line = '%-100s' % str_line
+                str_line = '%-104s' % str_line
                 if len(str_seriesInstanceUID):
                     str_line += ' │ ' + str_seriesInstanceUID
             else:
@@ -825,7 +828,7 @@ class Report(Base):
                 # except:
                 #     str_line = '[ --- ] '
                 str_line += str_seriesDescription
-                str_line = '%-55s' % str_line
+                str_line = '%-55s │ ' % str_line
                 str_line += str_seriesInstanceUID
             else:
                 str_line    = 'Invalid seriesIndex specified'
